==> epiphany-1.9.1.tar.gz: epiphany-1.9.1/embed/ephy-embed-type-builtins.c <==

/* Generated data (by glib-mkenums) */

#include "ephy-embed-type-builtins.h"


/* enumerations from "ephy-embed.h" */
#include "ephy-embed.h"
static const GFlagsValue _ephy_embed_net_state_values[] = {
  { EPHY_EMBED_STATE_UNKNOWN, "EPHY_EMBED_STATE_UNKNOWN", "unknown" },
  { EPHY_EMBED_STATE_START, "EPHY_EMBED_STATE_START", "start" },
  { EPHY_EMBED_STATE_REDIRECTING, "EPHY_EMBED_STATE_REDIRECTING", "redirecting" },
  { EPHY_EMBED_STATE_TRANSFERRING, "EPHY_EMBED_STATE_TRANSFERRING", "transferring" },
  { EPHY_EMBED_STATE_NEGOTIATING, "EPHY_EMBED_STATE_NEGOTIATING", "negotiating" },
  { EPHY_EMBED_STATE_STOP, "EPHY_EMBED_STATE_STOP", "stop" },
  { EPHY_EMBED_STATE_IS_REQUEST, "EPHY_EMBED_STATE_IS_REQUEST", "is-request" },
  { EPHY_EMBED_STATE_IS_DOCUMENT, "EPHY_EMBED_STATE_IS_DOCUMENT", "is-document" },
  { EPHY_EMBED_STATE_IS_NETWORK, "EPHY_EMBED_STATE_IS_NETWORK", "is-network" },
  { EPHY_EMBED_STATE_IS_WINDOW, "EPHY_EMBED_STATE_IS_WINDOW", "is-window" },
  { EPHY_EMBED_STATE_RESTORING, "EPHY_EMBED_STATE_RESTORING", "restoring" },
  { 0, NULL, NULL }
};

GType
ephy_embed_net_state_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_flags_register_static ("EphyEmbedNetState", _ephy_embed_net_state_values);

  return type;
}

static const GFlagsValue _ephy_embed_chrome_values[] = {
  { EPHY_EMBED_CHROME_MENUBAR, "EPHY_EMBED_CHROME_MENUBAR", "menubar" },
  { EPHY_EMBED_CHROME_TOOLBAR, "EPHY_EMBED_CHROME_TOOLBAR", "toolbar" },
  { EPHY_EMBED_CHROME_STATUSBAR, "EPHY_EMBED_CHROME_STATUSBAR", "statusbar" },
  { EPHY_EMBED_CHROME_BOOKMARKSBAR, "EPHY_EMBED_CHROME_BOOKMARKSBAR", "bookmarksbar" },
  { 0, NULL, NULL }
};

GType
ephy_embed_chrome_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_flags_register_static ("EphyEmbedChrome", _ephy_embed_chrome_values);

  return type;
}

static const GEnumValue _ephy_embed_print_preview_nav_type_values[] = {
  { EPHY_EMBED_PRINTPREVIEW_GOTO_PAGENUM, "EPHY_EMBED_PRINTPREVIEW_GOTO_PAGENUM", "goto-pagenum" },
  { EPHY_EMBED_PRINTPREVIEW_PREV_PAGE, "EPHY_EMBED_PRINTPREVIEW_PREV_PAGE", "prev-page" },
  { EPHY_EMBED_PRINTPREVIEW_NEXT_PAGE, "EPHY_EMBED_PRINTPREVIEW_NEXT_PAGE", "next-page" },
  { EPHY_EMBED_PRINTPREVIEW_HOME, "EPHY_EMBED_PRINTPREVIEW_HOME", "home" },
  { EPHY_EMBED_PRINTPREVIEW_END, "EPHY_EMBED_PRINTPREVIEW_END", "end" },
  { 0, NULL, NULL }
};

GType
ephy_embed_print_preview_nav_type_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_enum_register_static ("EphyEmbedPrintPreviewNavType", _ephy_embed_print_preview_nav_type_values);

  return type;
}

static const GEnumValue _ephy_embed_security_level_values[] = {
  { EPHY_EMBED_STATE_IS_UNKNOWN, "EPHY_EMBED_STATE_IS_UNKNOWN", "unknown" },
  { EPHY_EMBED_STATE_IS_INSECURE, "EPHY_EMBED_STATE_IS_INSECURE", "insecure" },
  { EPHY_EMBED_STATE_IS_BROKEN, "EPHY_EMBED_STATE_IS_BROKEN", "broken" },
  { EPHY_EMBED_STATE_IS_SECURE_LOW, "EPHY_EMBED_STATE_IS_SECURE_LOW", "secure-low" },
  { EPHY_EMBED_STATE_IS_SECURE_MED, "EPHY_EMBED_STATE_IS_SECURE_MED", "secure-med" },
  { EPHY_EMBED_STATE_IS_SECURE_HIGH, "EPHY_EMBED_STATE_IS_SECURE_HIGH", "secure-high" },
  { 0, NULL, NULL }
};

GType
ephy_embed_security_level_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_enum_register_static ("EphyEmbedSecurityLevel", _ephy_embed_security_level_values);

  return type;
}

static const GEnumValue _ephy_embed_document_type_values[] = {
  { EPHY_EMBED_DOCUMENT_HTML, "EPHY_EMBED_DOCUMENT_HTML", "html" },
  { EPHY_EMBED_DOCUMENT_XML, "EPHY_EMBED_DOCUMENT_XML", "xml" },
  { EPHY_EMBED_DOCUMENT_IMAGE, "EPHY_EMBED_DOCUMENT_IMAGE", "image" },
  { EPHY_EMBED_DOCUMENT_OTHER, "EPHY_EMBED_DOCUMENT_OTHER", "other" },
  { 0, NULL, NULL }
};

GType
ephy_embed_document_type_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_enum_register_static ("EphyEmbedDocumentType", _ephy_embed_document_type_values);

  return type;
}


/* enumerations from "ephy-embed-event.h" */
#include "ephy-embed-event.h"
static const GFlagsValue _ephy_embed_event_context_values[] = {
  { EPHY_EMBED_CONTEXT_NONE, "EPHY_EMBED_CONTEXT_NONE", "none" },
  { EPHY_EMBED_CONTEXT_DEFAULT, "EPHY_EMBED_CONTEXT_DEFAULT", "default" },
  { EPHY_EMBED_CONTEXT_LINK, "EPHY_EMBED_CONTEXT_LINK", "link" },
  { EPHY_EMBED_CONTEXT_IMAGE, "EPHY_EMBED_CONTEXT_IMAGE", "image" },
  { EPHY_EMBED_CONTEXT_DOCUMENT, "EPHY_EMBED_CONTEXT_DOCUMENT", "document" },
  { EPHY_EMBED_CONTEXT_INPUT, "EPHY_EMBED_CONTEXT_INPUT", "input" },
  { EPHY_EMBED_CONTEXT_INPUT_PASSWORD, "EPHY_EMBED_CONTEXT_INPUT_PASSWORD", "input-password" },
  { EPHY_EMBED_CONTEXT_XUL, "EPHY_EMBED_CONTEXT_XUL", "xul" },
  { EPHY_EMBED_CONTEXT_EMAIL_LINK, "EPHY_EMBED_CONTEXT_EMAIL_LINK", "email-link" },
  { 0, NULL, NULL }
};

GType
ephy_embed_event_context_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_flags_register_static ("EphyEmbedEventContext", _ephy_embed_event_context_values);

  return type;
}


/* enumerations from "ephy-embed-persist.h" */
#include "ephy-embed-persist.h"
static const GFlagsValue _ephy_embed_persist_flags_values[] = {
  { EPHY_EMBED_PERSIST_COPY_PAGE, "EPHY_EMBED_PERSIST_COPY_PAGE", "copy-page" },
  { EPHY_EMBED_PERSIST_MAINDOC, "EPHY_EMBED_PERSIST_MAINDOC", "maindoc" },
  { EPHY_EMBED_PERSIST_NO_VIEW, "EPHY_EMBED_PERSIST_NO_VIEW", "no-view" },
  { EPHY_EMBED_PERSIST_ASK_DESTINATION, "EPHY_EMBED_PERSIST_ASK_DESTINATION", "ask-destination" },
  { EPHY_EMBED_PERSIST_DO_CONVERSION, "EPHY_EMBED_PERSIST_DO_CONVERSION", "do-conversion" },
  { EPHY_EMBED_PERSIST_FROM_CACHE, "EPHY_EMBED_PERSIST_FROM_CACHE", "from-cache" },
  { EPHY_EMBED_PERSIST_NO_CERTDIALOGS, "EPHY_EMBED_PERSIST_NO_CERTDIALOGS", "no-certdialogs" },
  { 0, NULL, NULL }
};

GType
ephy_embed_persist_flags_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_flags_register_static ("EphyEmbedPersistFlags", _ephy_embed_persist_flags_values);

  return type;
}


/* enumerations from "ephy-embed-single.h" */
#include "ephy-embed-single.h"
static const GEnumValue _ephy_content_check_type_values[] = {
  { EPHY_CONTENT_CHECK_TYPE_OTHER, "EPHY_CONTENT_CHECK_TYPE_OTHER", "other" },
  { EPHY_CONTENT_CHECK_TYPE_SCRIPT, "EPHY_CONTENT_CHECK_TYPE_SCRIPT", "script" },
  { EPHY_CONTENT_CHECK_TYPE_IMAGE, "EPHY_CONTENT_CHECK_TYPE_IMAGE", "image" },
  { EPHY_CONTENT_CHECK_TYPE_STYLESHEET, "EPHY_CONTENT_CHECK_TYPE_STYLESHEET", "stylesheet" },
  { EPHY_CONTENT_CHECK_TYPE_OBJECT, "EPHY_CONTENT_CHECK_TYPE_OBJECT", "object" },
  { EPHY_CONTENT_CHECK_TYPE_DOCUMENT, "EPHY_CONTENT_CHECK_TYPE_DOCUMENT", "document" },
  { EPHY_CONTENT_CHECK_TYPE_SUBDOCUMENT, "EPHY_CONTENT_CHECK_TYPE_SUBDOCUMENT", "subdocument" },
  { EPHY_CONTENT_CHECK_TYPE_REFRESH, "EPHY_CONTENT_CHECK_TYPE_REFRESH", "refresh" },
  { 0, NULL, NULL }
};

GType
ephy_content_check_type_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_enum_register_static ("EphyContentCheckType", _ephy_content_check_type_values);

  return type;
}


/* enumerations from "ephy-permission-manager.h" */
#include "ephy-permission-manager.h"
static const GEnumValue _ephy_permission_values[] = {
  { EPHY_PERMISSION_ALLOWED, "EPHY_PERMISSION_ALLOWED", "allowed" },
  { EPHY_PERMISSION_DENIED, "EPHY_PERMISSION_DENIED", "denied" },
  { EPHY_PERMISSION_DEFAULT, "EPHY_PERMISSION_DEFAULT", "default" },
  { 0, NULL, NULL }
};

GType
ephy_permission_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_enum_register_static ("EphyPermission", _ephy_permission_values);

  return type;
}


/* Generated data ends here */

==> epiphany-1.9.3.1.tar.gz: epiphany-1.9.3.1/embed/ephy-embed-type-builtins.c <==

/* Generated data (by glib-mkenums) */

#include "ephy-embed-type-builtins.h"


/* enumerations from "ephy-embed.h" */
#include "ephy-embed.h"
static const GFlagsValue _ephy_embed_net_state_values[] = {
  { EPHY_EMBED_STATE_UNKNOWN, "EPHY_EMBED_STATE_UNKNOWN", "unknown" },
  { EPHY_EMBED_STATE_START, "EPHY_EMBED_STATE_START", "start" },
  { EPHY_EMBED_STATE_REDIRECTING, "EPHY_EMBED_STATE_REDIRECTING", "redirecting" },
  { EPHY_EMBED_STATE_TRANSFERRING, "EPHY_EMBED_STATE_TRANSFERRING", "transferring" },
  { EPHY_EMBED_STATE_NEGOTIATING, "EPHY_EMBED_STATE_NEGOTIATING", "negotiating" },
  { EPHY_EMBED_STATE_STOP, "EPHY_EMBED_STATE_STOP", "stop" },
  { EPHY_EMBED_STATE_IS_REQUEST, "EPHY_EMBED_STATE_IS_REQUEST", "is-request" },
  { EPHY_EMBED_STATE_IS_DOCUMENT, "EPHY_EMBED_STATE_IS_DOCUMENT", "is-document" },
  { EPHY_EMBED_STATE_IS_NETWORK, "EPHY_EMBED_STATE_IS_NETWORK", "is-network" },
  { EPHY_EMBED_STATE_IS_WINDOW, "EPHY_EMBED_STATE_IS_WINDOW", "is-window" },
  { EPHY_EMBED_STATE_RESTORING, "EPHY_EMBED_STATE_RESTORING", "restoring" },
  { 0, NULL, NULL }
};

GType
ephy_embed_net_state_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_flags_register_static ("EphyEmbedNetState", _ephy_embed_net_state_values);

  return type;
}

static const GFlagsValue _ephy_embed_chrome_values[] = {
  { EPHY_EMBED_CHROME_MENUBAR, "EPHY_EMBED_CHROME_MENUBAR", "menubar" },
  { EPHY_EMBED_CHROME_TOOLBAR, "EPHY_EMBED_CHROME_TOOLBAR", "toolbar" },
  { EPHY_EMBED_CHROME_STATUSBAR, "EPHY_EMBED_CHROME_STATUSBAR", "statusbar" },
  { EPHY_EMBED_CHROME_BOOKMARKSBAR, "EPHY_EMBED_CHROME_BOOKMARKSBAR", "bookmarksbar" },
  { 0, NULL, NULL }
};

GType
ephy_embed_chrome_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_flags_register_static ("EphyEmbedChrome", _ephy_embed_chrome_values);

  return type;
}

static const GEnumValue _ephy_embed_print_preview_nav_type_values[] = {
  { EPHY_EMBED_PRINTPREVIEW_GOTO_PAGENUM, "EPHY_EMBED_PRINTPREVIEW_GOTO_PAGENUM", "goto-pagenum" },
  { EPHY_EMBED_PRINTPREVIEW_PREV_PAGE, "EPHY_EMBED_PRINTPREVIEW_PREV_PAGE", "prev-page" },
  { EPHY_EMBED_PRINTPREVIEW_NEXT_PAGE, "EPHY_EMBED_PRINTPREVIEW_NEXT_PAGE", "next-page" },
  { EPHY_EMBED_PRINTPREVIEW_HOME, "EPHY_EMBED_PRINTPREVIEW_HOME", "home" },
  { EPHY_EMBED_PRINTPREVIEW_END, "EPHY_EMBED_PRINTPREVIEW_END", "end" },
  { 0, NULL, NULL }
};

GType
ephy_embed_print_preview_nav_type_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_enum_register_static ("EphyEmbedPrintPreviewNavType", _ephy_embed_print_preview_nav_type_values);

  return type;
}

static const GEnumValue _ephy_embed_security_level_values[] = {
  { EPHY_EMBED_STATE_IS_UNKNOWN, "EPHY_EMBED_STATE_IS_UNKNOWN", "unknown" },
  { EPHY_EMBED_STATE_IS_INSECURE, "EPHY_EMBED_STATE_IS_INSECURE", "insecure" },
  { EPHY_EMBED_STATE_IS_BROKEN, "EPHY_EMBED_STATE_IS_BROKEN", "broken" },
  { EPHY_EMBED_STATE_IS_SECURE_LOW, "EPHY_EMBED_STATE_IS_SECURE_LOW", "secure-low" },
  { EPHY_EMBED_STATE_IS_SECURE_MED, "EPHY_EMBED_STATE_IS_SECURE_MED", "secure-med" },
  { EPHY_EMBED_STATE_IS_SECURE_HIGH, "EPHY_EMBED_STATE_IS_SECURE_HIGH", "secure-high" },
  { 0, NULL, NULL }
};

GType
ephy_embed_security_level_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_enum_register_static ("EphyEmbedSecurityLevel", _ephy_embed_security_level_values);

  return type;
}

static const GEnumValue _ephy_embed_document_type_values[] = {
  { EPHY_EMBED_DOCUMENT_HTML, "EPHY_EMBED_DOCUMENT_HTML", "html" },
  { EPHY_EMBED_DOCUMENT_XML, "EPHY_EMBED_DOCUMENT_XML", "xml" },
  { EPHY_EMBED_DOCUMENT_IMAGE, "EPHY_EMBED_DOCUMENT_IMAGE", "image" },
  { EPHY_EMBED_DOCUMENT_OTHER, "EPHY_EMBED_DOCUMENT_OTHER", "other" },
  { 0, NULL, NULL }
};

GType
ephy_embed_document_type_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_enum_register_static ("EphyEmbedDocumentType", _ephy_embed_document_type_values);

  return type;
}


/* enumerations from "ephy-embed-event.h" */
#include "ephy-embed-event.h"
static const GFlagsValue _ephy_embed_event_context_values[] = {
  { EPHY_EMBED_CONTEXT_NONE, "EPHY_EMBED_CONTEXT_NONE", "none" },
  { EPHY_EMBED_CONTEXT_DEFAULT, "EPHY_EMBED_CONTEXT_DEFAULT", "default" },
  { EPHY_EMBED_CONTEXT_LINK, "EPHY_EMBED_CONTEXT_LINK", "link" },
  { EPHY_EMBED_CONTEXT_IMAGE, "EPHY_EMBED_CONTEXT_IMAGE", "image" },
  { EPHY_EMBED_CONTEXT_DOCUMENT, "EPHY_EMBED_CONTEXT_DOCUMENT", "document" },
  { EPHY_EMBED_CONTEXT_INPUT, "EPHY_EMBED_CONTEXT_INPUT", "input" },
  { EPHY_EMBED_CONTEXT_INPUT_PASSWORD, "EPHY_EMBED_CONTEXT_INPUT_PASSWORD", "input-password" },
  { EPHY_EMBED_CONTEXT_XUL, "EPHY_EMBED_CONTEXT_XUL", "xul" },
  { EPHY_EMBED_CONTEXT_EMAIL_LINK, "EPHY_EMBED_CONTEXT_EMAIL_LINK", "email-link" },
  { 0, NULL, NULL }
};

GType
ephy_embed_event_context_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_flags_register_static ("EphyEmbedEventContext", _ephy_embed_event_context_values);

  return type;
}


/* enumerations from "ephy-embed-persist.h" */
#include "ephy-embed-persist.h"
static const GFlagsValue _ephy_embed_persist_flags_values[] = {
  { EPHY_EMBED_PERSIST_COPY_PAGE, "EPHY_EMBED_PERSIST_COPY_PAGE", "copy-page" },
  { EPHY_EMBED_PERSIST_MAINDOC, "EPHY_EMBED_PERSIST_MAINDOC", "maindoc" },
  { EPHY_EMBED_PERSIST_NO_VIEW, "EPHY_EMBED_PERSIST_NO_VIEW", "no-view" },
  { EPHY_EMBED_PERSIST_ASK_DESTINATION, "EPHY_EMBED_PERSIST_ASK_DESTINATION", "ask-destination" },
  { EPHY_EMBED_PERSIST_DO_CONVERSION, "EPHY_EMBED_PERSIST_DO_CONVERSION", "do-conversion" },
  { EPHY_EMBED_PERSIST_FROM_CACHE, "EPHY_EMBED_PERSIST_FROM_CACHE", "from-cache" },
  { EPHY_EMBED_PERSIST_NO_CERTDIALOGS, "EPHY_EMBED_PERSIST_NO_CERTDIALOGS", "no-certdialogs" },
  { 0, NULL, NULL }
};

GType
ephy_embed_persist_flags_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_flags_register_static ("EphyEmbedPersistFlags", _ephy_embed_persist_flags_values);

  return type;
}


/* enumerations from "ephy-permission-manager.h" */
#include "ephy-permission-manager.h"
static const GEnumValue _ephy_permission_values[] = {
  { EPHY_PERMISSION_ALLOWED, "EPHY_PERMISSION_ALLOWED", "allowed" },
  { EPHY_PERMISSION_DENIED, "EPHY_PERMISSION_DENIED", "denied" },
  { EPHY_PERMISSION_DEFAULT, "EPHY_PERMISSION_DEFAULT", "default" },
  { 0, NULL, NULL }
};

GType
ephy_permission_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_enum_register_static ("EphyPermission", _ephy_permission_values);

  return type;
}


/* enumerations from "ephy-x509-cert.h" */
#include "ephy-x509-cert.h"
static const GEnumValue _ephy_x509_cert_type_values[] = {
  { PERSONAL_CERTIFICATE, "PERSONAL_CERTIFICATE", "personal-certificate" },
  { SERVER_CERTIFICATE, "SERVER_CERTIFICATE", "server-certificate" },
  { CA_CERTIFICATE, "CA_CERTIFICATE", "ca-certificate" },
  { 0, NULL, NULL }
};

GType
ephy_x509_cert_type_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_enum_register_static ("EphyX509CertType", _ephy_x509_cert_type_values);

  return type;
}


/* Generated data ends here */
